@@ -78,9 +78,6 @@
 /* IJG JPEG codec */
 #define HAVE_JPEG
 
-/* libpng/png.h needs to be included */
-/* #undef HAVE_LIBPNG_PNG_H */
-
 /* GDCM DICOM codec */
 /* #undef HAVE_GDCM */
 
@@ -129,7 +126,7 @@
 
 /* Define if your processor stores words with the most significant byte
    first (like Motorola and SPARC, unlike Intel and VAX). */
-#define WORDS_BIGENDIAN
+/* #undef WORDS_BIGENDIAN */
 
 /* VA library (libva) */
 /* #undef HAVE_VA */
@@ -150,6 +147,6 @@
 #define OPENCV_TRACE
 
 /* Library QR-code decoding */
-#define HAVE_QUIRC
+/* #undef HAVE_QUIRC */
 
 #endif // OPENCV_CVCONFIG_H_INCLUDED
